@@ -1,5 +1,5 @@
-mod protocol;
-mod session;
+pub mod protocol;
+pub mod session;
 
 use crate::session::Session;
 use crate::protocol::{Package, Parsable};
@@ -144,6 +144,20 @@ impl Connection{
             }
         }
     }
+    pub async fn send_msg(&mut self, key: String, msg: Vec<u8>) -> Result<(), ()>{
+        match self.socket.as_mut(){
+            None => { Err(()) }
+            Some(socket) => {
+                let res = socket.send(Message::Binary(
+                    protocol::MsgPackage{int_key: protocol::hash(&key), str_key: key, payload: msg}.to_bytes()
+                )).await;
+                match res{
+                    Ok(_) => { Ok(()) }
+                    Err(_) => { Err(()) }
+                }
+            }
+        }
+    }
     pub async fn next(&mut self) -> Result<protocol::Package, ()>{
         match self.socket.as_mut(){
             None => { Err(()) }
